@@ -4,8 +4,10 @@
 #'@param nodes : a vector of nodes id. NULL for \code{visUncollapse} for open all collapsed nodes
 #'@param fit : Optional. Boolean. Default to FALSE. Call fit method after collapse/uncollapse event ?
 #'@param resetHighlight : Optional. Boolean. Default to TRUE to reset highlighted nodes after collapse/uncollapse event.
+#'@param keepCoord : Optional. Boolean. Default to TRUE to keep nodes coordinates on collapse
 #'@param clusterOptions : Optional. List. Defaut to NULL. A list of all options you want to pass to cluster collapsed node
-#'  
+#'@param labelSuffix : Optional. Character. Use node label + suffix or just suffix. Default to '(cluster)'
+#'
 #'@seealso \link{visNodes} for nodes options, \link{visEdges} for edges options, \link{visGroups} for groups options, 
 #'\link{visLegend} for adding legend, \link{visOptions} for custom option, \link{visLayout} & \link{visHierarchicalLayout} for layout, 
 #'\link{visPhysics} for control physics, \link{visInteraction} for interaction, \link{visNetworkProxy} & \link{visFocus} & \link{visFit} for animation within shiny,
@@ -28,7 +30,8 @@
 #'@references See online documentation \url{http://datastorm-open.github.io/visNetwork/}
 #'@name visNetwork-collapse
 #' 
-visCollapse <- function(graph, nodes, fit = FALSE, resetHighlight = TRUE, clusterOptions = NULL){
+visCollapse <- function(graph, nodes, fit = FALSE, resetHighlight = TRUE, 
+                        clusterOptions = NULL, labelSuffix = "(cluster)"){
 
   if(!any(class(graph) %in% "visNetwork_Proxy")){
     stop("Can't use visCollapse with visNetwork object. Only within shiny & using visNetworkProxy")
@@ -38,7 +41,8 @@ visCollapse <- function(graph, nodes, fit = FALSE, resetHighlight = TRUE, cluste
     nodes <- list(nodes)
   }
   
-  data <- list(id = graph$id, nodes = nodes, fit = fit, resetHighlight = resetHighlight)
+  data <- list(id = graph$id, nodes = nodes, fit = fit, 
+               resetHighlight = resetHighlight, labelSuffix = labelSuffix)
   data$clusterOptions <- clusterOptions
   
   graph$session$sendCustomMessage("visShinyCollapse", data)
@@ -49,13 +53,13 @@ visCollapse <- function(graph, nodes, fit = FALSE, resetHighlight = TRUE, cluste
 #' @name visNetwork-collapse
 #'
 #' @export  
-visUncollapse <- function(graph, nodes = NULL, fit = FALSE, resetHighlight = TRUE){
+visUncollapse <- function(graph, nodes = NULL, fit = FALSE, resetHighlight = TRUE, keepCoord = TRUE){
   
   if(!any(class(graph) %in% "visNetwork_Proxy")){
     stop("Can't use visUncollapse with visNetwork object. Only within shiny & using visNetworkProxy")
   }
   
-  data <- list(id = graph$id, fit = fit, resetHighlight = resetHighlight)
+  data <- list(id = graph$id, fit = fit, resetHighlight = resetHighlight, keepCoord = keepCoord)
   
   if(!is.null(nodes)){
     if(length(nodes) == 1){
